/*
 * Copyright (c) 2007 Extreme! Lab, Indiana University. All rights reserved.
 *
 * This software is open source. See the bottom of this file for the license.
 *
 * $Id: LeadContextHeaderHelper.java,v 1.2 2007/06/23 15:08:51 sshirasu Exp $
 */
package edu.indiana.extreme.xbaya.lead;

import java.net.URI;

import wsmg.WseClientAPI;
import xsul.lead.LeadContextHeader;
import xsul.ws_addressing.WsaEndpointReference;
import edu.indiana.extreme.xbaya.XBayaConfiguration;
import edu.indiana.extreme.xbaya.XBayaConstants;
import edu.indiana.extreme.xbaya.monitor.MonitorConfiguration;
import edu.indiana.extreme.xbaya.mylead.MyLeadConfiguration;
import edu.indiana.extreme.xbaya.util.WSDLUtil;
import edu.indiana.extreme.xbaya.wf.Workflow;

/**
 * @author Satoshi Shirasuna
 */
public class LeadContextHeaderHelper {

    /**
     * DEFAULT_USER
     */
    private static final String DEFAULT_USER = "xbaya-user";

    /**
     * DEFAULT_EXPERIMENT
     */
    private static final String DEFAULT_EXPERIMENT = "xbaya-experiment";

    private LeadContextHeader leadContextHeader;

    /**
     * Constructs a LeadContextHeaderHelper.
     * 
     */
    public LeadContextHeaderHelper() {
        // The default experiment and user will be will be overwritten.
        this.leadContextHeader = new LeadContextHeader(DEFAULT_EXPERIMENT,
                DEFAULT_USER);
    }

    /**
     * @return The leadContextHeader.
     */
    public LeadContextHeader getLeadContextHeader() {
        return this.leadContextHeader;
    }

    /**
     * @param user
     */
    public void setUser(String user) {
        if (user == null || user.length() == 0) {
            user = DEFAULT_USER;
        }
        this.leadContextHeader.setUserDn(user);
    }

    /**
     * @param workflowTemplateID
     */
    public void setWorkflowTemplateID(URI workflowTemplateID) {
        if (workflowTemplateID != null) {
            this.leadContextHeader.setWorkflowTemplateId(workflowTemplateID);
        }
    }

    /**
     * @param workflowInstanceID
     */
    public void setWorkflowInstanceID(URI workflowInstanceID) {
        if (workflowInstanceID != null) {
            this.leadContextHeader.setWorkflowInstanceId(workflowInstanceID);
        }
    }

    /**
     * @param myLeadAgentURL
     */
    public void setMyLeadAgentURL(URI myLeadAgentURL) {
        if (myLeadAgentURL != null) {
            this.leadContextHeader.setMyleadAgentUrl(WSDLUtil
                    .appendWSDLQuary(myLeadAgentURL));
        }
    }

    /**
     * @param brokerURL
     * @param topic
     */
    public void setEventSink(URI brokerURL, String topic) {
        if (brokerURL != null) {
            if (topic == null || topic.length() == 0) {
                topic = XBayaConstants.DEFAULT_TOPIC;
            }
            WsaEndpointReference eventSink = WseClientAPI
                    .createEndpointReference(brokerURL.toString(), topic);
            this.leadContextHeader.setEventSink(eventSink);
        }
    }

    /**
     * @param resourceCatalogURL
     */
    public void setResourceCatalogURL(URI resourceCatalogURL) {
        if (resourceCatalogURL != null) {
            this.leadContextHeader.setResourceCatalogUrl(WSDLUtil
                    .appendWSDLQuary(resourceCatalogURL));
        }
    }

    /**
     * @param xRegistryURL
     */
    public void setXRegistryURL(URI xRegistryURL) {
        if (xRegistryURL != null) {
            this.leadContextHeader.setXRegistryUrl(WSDLUtil
                    .appendWSDLQuary(xRegistryURL));
        }
    }

    /**
     * @param gFacURL
     */
    public void setGFacURL(URI gFacURL) {
        if (gFacURL != null) {
            this.leadContextHeader
                    .setGfacUrl(WSDLUtil.appendWSDLQuary(gFacURL));
        }
    }

    //
    // The followings are higer-level APIs.
    //

    /**
     * @param workflow
     */
    public void setWorkflow(Workflow workflow) {
        if (workflow != null) {
            setWorkflowTemplateID(workflow.getGPELTemplateID());
            setWorkflowInstanceID(workflow.getGPELInstanceID());
        }
    }

    /**
     * @param myleadConfiguration
     */
    public void setMyLeadConfiguration(MyLeadConfiguration myleadConfiguration) {
        setUser(myleadConfiguration.getUser());
        setMyLeadAgentURL(myleadConfiguration.getURL());
    }

    /**
     * @param monitorConfiguration
     */
    public void setMonitorConfiguration(
            MonitorConfiguration monitorConfiguration) {
        setEventSink(monitorConfiguration.getBrokerURL(), monitorConfiguration
                .getTopic());
    }

    /**
     * This method has to be called before setMyLeadConfiguration() or
     * setMonitorConfiguration because this will overwrite some variables.
     * 
     * @param xbayaConfiguration
     */
    public void setXBayaConfiguration(XBayaConfiguration xbayaConfiguration) {
        setResourceCatalogURL(xbayaConfiguration.getResourceCatalogURL());
        setXRegistryURL(xbayaConfiguration.getXRegistryURL());
        setGFacURL(xbayaConfiguration.getGFacURL());

        // The followings might overwrite some variables.
        setWorkflowTemplateID(xbayaConfiguration.getGPELTemplateID());
        setWorkflowInstanceID(xbayaConfiguration.getGPELInstanceID());
        setUser(xbayaConfiguration.getMyLeadUser());
        setMyLeadAgentURL(xbayaConfiguration.getMyLeadAgentURL());
        setEventSink(xbayaConfiguration.getBrokerURL(), xbayaConfiguration
                .getTopic());
    }

}

/*
 * Indiana University Extreme! Lab Software License, Version 1.2
 * 
 * Copyright (c) 2007 The Trustees of Indiana University. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1) All redistributions of source code must retain the above copyright notice,
 * the list of authors in the original source code, this list of conditions and
 * the disclaimer listed in this license;
 * 
 * 2) All redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the disclaimer listed in this license in
 * the documentation and/or other materials provided with the distribution;
 * 
 * 3) Any documentation included with all redistributions must include the
 * following acknowledgement:
 * 
 * "This product includes software developed by the Indiana University Extreme!
 * Lab. For further information please visit http://www.extreme.indiana.edu/"
 * 
 * Alternatively, this acknowledgment may appear in the software itself, and
 * wherever such third-party acknowledgments normally appear.
 * 
 * 4) The name "Indiana University" or "Indiana University Extreme! Lab" shall
 * not be used to endorse or promote products derived from this software without
 * prior written permission from Indiana University. For written permission,
 * please contact http://www.extreme.indiana.edu/.
 * 
 * 5) Products derived from this software may not use "Indiana University" name
 * nor may "Indiana University" appear in their name, without prior written
 * permission of the Indiana University.
 * 
 * Indiana University provides no reassurances that the source code provided
 * does not infringe the patent or any other intellectual property rights of any
 * other entity. Indiana University disclaims any liability to any recipient for
 * claims brought by any other entity based on infringement of intellectual
 * property rights or otherwise.
 * 
 * LICENSEE UNDERSTANDS THAT SOFTWARE IS PROVIDED "AS IS" FOR WHICH NO
 * WARRANTIES AS TO CAPABILITIES OR ACCURACY ARE MADE. INDIANA UNIVERSITY GIVES
 * NO WARRANTIES AND MAKES NO REPRESENTATION THAT SOFTWARE IS FREE OF
 * INFRINGEMENT OF THIRD PARTY PATENT, COPYRIGHT, OR OTHER PROPRIETARY RIGHTS.
 * INDIANA UNIVERSITY MAKES NO WARRANTIES THAT SOFTWARE IS FREE FROM "BUGS",
 * "VIRUSES", "TROJAN HORSES", "TRAP DOORS", "WORMS", OR OTHER HARMFUL CODE.
 * LICENSEE ASSUMES THE ENTIRE RISK AS TO THE PERFORMANCE OF SOFTWARE AND/OR
 * ASSOCIATED MATERIALS, AND TO THE PERFORMANCE AND VALIDITY OF INFORMATION
 * GENERATED USING SOFTWARE.
 */
